<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sr">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About %1</source>
        <translation>О %1</translation>
    </message>
    <message>
        <source>Authors</source>
        <translation>Аутори</translation>
    </message>
    <message>
        <source>License</source>
        <translation>Лиценца</translation>
    </message>
    <message>
        <source>Lightweight WebKit-based web browser</source>
        <translation>Лагани веб прегледач базиран на Вебкиту</translation>
    </message>
    <message utf8="true">
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot;font-size:9pt;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Copyright © 2007-2009 Benjamin C. Meyer &amp;lt;&lt;a href=&quot;mailto:ben@meyerhome.net&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;ben@meyerhome.net&lt;/span&gt;&lt;/a&gt;&amp;gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot;font-size:9pt;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Copyright © 2007-2009 Benjamin C. Meyer &amp;lt;&lt;a href=&quot;mailto:ben@meyerhome.net&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;ben@meyerhome.net&lt;/span&gt;&lt;/a&gt;&amp;gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>&lt;a href=&quot;http://arora-browser.org&quot;&gt;http://arora-browser.org&lt;/a&gt;</source>
        <translation>&lt;a href=&quot;http://arora-browser.org&quot;&gt;http://arora-browser.org/&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Затвори</translation>
    </message>
    <message>
        <source>WebKit version: %1</source>
        <translation>Верзија Вебкита: %1</translation>
    </message>
</context>
<context>
    <name>AcceptLanguage</name>
    <message>
        <source>Languages</source>
        <translation>Језици</translation>
    </message>
    <message>
        <source>Languages: in order of preference:</source>
        <translation>Језици према редоследу пожељности:</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>&amp;Горе</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>&amp;Доле</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Уклони</translation>
    </message>
    <message>
        <source>Add...</source>
        <translation>Додај...</translation>
    </message>
</context>
<context>
    <name>AdBlockBlockedNetworkReply</name>
    <message>
        <source>Blocked by AdBlockRule: %1</source>
        <translation>Заустављено Адблоковим правилом: %1</translation>
    </message>
</context>
<context>
    <name>AdBlockDialog</name>
    <message>
        <source>Add Custom Rule</source>
        <translation>Додај прилагођено правило</translation>
    </message>
    <message>
        <source>Learn more about writing rules...</source>
        <translation>Научите више о писању правила...</translation>
    </message>
    <message>
        <source>Update Subscription</source>
        <translation>Ажурирај претплате</translation>
    </message>
    <message>
        <source>Browse Subscriptions...</source>
        <translation>Прегледај претплате...</translation>
    </message>
    <message>
        <source>Remove Subscription</source>
        <translation>Уклони претплату</translation>
    </message>
    <message>
        <source>AdBlock Configuration</source>
        <translation>Подешавање Адблока</translation>
    </message>
    <message>
        <source>Enable AdBlock</source>
        <translation>Омогући Адблок</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Радња</translation>
    </message>
</context>
<context>
    <name>AdBlockManager</name>
    <message>
        <source>Custom Rules</source>
        <translation>Прилагођена правила</translation>
    </message>
</context>
<context>
    <name>AdBlockModel</name>
    <message>
        <source>Rule</source>
        <translation>Правило</translation>
    </message>
</context>
<context>
    <name>AdBlockSchemeAccessHandler</name>
    <message>
        <source>Subscribe?</source>
        <translation>Претплати се?</translation>
    </message>
    <message>
        <source>Subscribe to this AdBlock subscription?
%1</source>
        <translation>Претпалтити се на ову Адблок претплату?
%1</translation>
    </message>
</context>
<context>
    <name>AddBookmarkDialog</name>
    <message>
        <source>Add Bookmark</source>
        <translation>Додај маркер</translation>
    </message>
    <message>
        <source>Type a name for the bookmark, and choose where to keep it.</source>
        <translation>Унесите име маркера и изаберите где га сачувати.</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>УРЛ</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Наслов</translation>
    </message>
    <message>
        <source>Add Folder</source>
        <translation>Додај фасциклу</translation>
    </message>
</context>
<context>
    <name>AutoFillDialog</name>
    <message>
        <source>Form Passwords</source>
        <translation>Лозинке за обрасце</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Уклони</translation>
    </message>
    <message>
        <source>Remove All</source>
        <translation>Уклони све</translation>
    </message>
</context>
<context>
    <name>AutoFillManager</name>
    <message>
        <source>&lt;b&gt;Would you like to save this password?&lt;/b&gt;&lt;br&gt;         To review passwords you have saved and remove them, open the AutoFill pane of preferences.</source>
        <translation>&lt;b&gt;Желите ли да сачувате ову лозинку?&lt;/b&gt;&lt;br&gt;         Да би прегледали или уклонили сачуване лозинке користите панел самопопуњавања у подешавањима.</translation>
    </message>
    <message>
        <source>Never for this site</source>
        <translation>Никад за овај сајт</translation>
    </message>
    <message>
        <source>Not now</source>
        <translation>Не сад</translation>
    </message>
</context>
<context>
    <name>AutoFillModel</name>
    <message>
        <source>WebSite</source>
        <translation>Веб сајт</translation>
    </message>
    <message>
        <source>User Name</source>
        <translation>Корисничко име</translation>
    </message>
</context>
<context>
    <name>BookmarksDialog</name>
    <message>
        <source>Open</source>
        <translation>Отвори</translation>
    </message>
    <message>
        <source>Open in New Tab</source>
        <translation>Отвори у новом језичку</translation>
    </message>
    <message>
        <source>Edit Name</source>
        <translation>Уреди име</translation>
    </message>
    <message>
        <source>Edit Address</source>
        <translation>Уреди адресу</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Обриши</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Нова фасцикла</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Маркери</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Уклони</translation>
    </message>
    <message>
        <source>Add Folder</source>
        <translation>Додај фасциклу</translation>
    </message>
</context>
<context>
    <name>BookmarksManager</name>
    <message>
        <source>Bookmarks Bar</source>
        <translation>Трака маркера</translation>
    </message>
    <message>
        <source>Bookmarks Menu</source>
        <translation>Мени маркера</translation>
    </message>
    <message>
        <source>Error when loading bookmarks on line %1, column %2:
%3</source>
        <translation>Грешка при учитавању маркера у реду %1, колона %2:
%3 </translation>
    </message>
    <message>
        <source>Toolbar Bookmarks</source>
        <translation>Маркери у траци алатки</translation>
    </message>
    <message>
        <source>Menu</source>
        <translation>Мени</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Отвори фајл</translation>
    </message>
    <message>
        <source>Imported %1</source>
        <translation>Увезено %1</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>Сачувај фајл</translation>
    </message>
    <message>
        <source>%1 Bookmarks.xbel</source>
        <translation>%1 Маркери.xbel</translation>
    </message>
    <message>
        <source>Export error</source>
        <translation>Грешка при извозу</translation>
    </message>
    <message>
        <source>error saving bookmarks</source>
        <translation>грешка при чувању маркера</translation>
    </message>
    <message>
        <source>Remove Bookmark</source>
        <translation>Уклони маркер</translation>
    </message>
    <message>
        <source>Insert Bookmark</source>
        <translation>Унеси маркер</translation>
    </message>
    <message>
        <source>Name Change</source>
        <comment>Undo bookmark title change</comment>
        <translation>Промена имена</translation>
    </message>
    <message>
        <source>Address Change</source>
        <comment>Undo bookmark url change</comment>
        <translation>Промена адресе</translation>
    </message>
    <message>
        <source>XBEL bookmarks</source>
        <translation>ИксБЕЛ маркери</translation>
    </message>
    <message>
        <source>HTML Netscape bookmarks</source>
        <translation>ХТМЛ Нетскејп маркери</translation>
    </message>
    <message>
        <source>htmlToXBel tool required</source>
        <translation>Неопходна је Хтмл-У-ИксБЕЛ алатка</translation>
    </message>
    <message>
        <source>htmlToXBel tool, which is shipped with Arora and is needed to import HTML bookmarks, is not installed or not available in the search paths.</source>
        <translation>Хтмл-У-ИксБЕЛ алатка, која се деставља са Арором и неопходна је за увоз ХТМЛ маркера, није инсталирана или се не налази у претраженим путањама.</translation>
    </message>
    <message>
        <source>Loading Bookmark</source>
        <translation>Учитавам маркер</translation>
    </message>
    <message>
        <source>Error when loading HTML bookmarks: %1
</source>
        <translation>Грешка при учитавању ХТМЛ маркера: %1
</translation>
    </message>
</context>
<context>
    <name>BookmarksMenu</name>
    <message>
        <source>Open in Tabs</source>
        <translation>Отвори у језичцима</translation>
    </message>
</context>
<context>
    <name>BookmarksModel</name>
    <message>
        <source>Title</source>
        <translation>Наслов</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Адреса</translation>
    </message>
</context>
<context>
    <name>BookmarksToolBar</name>
    <message>
        <source>Open</source>
        <translation>Отвори</translation>
    </message>
    <message>
        <source>Open in New &amp;Tab</source>
        <translation>Отвори у новом &amp;језичку</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Уклони</translation>
    </message>
    <message>
        <source>Add Bookmark...</source>
        <translation>Додај маркер...</translation>
    </message>
    <message>
        <source>Add Folder...</source>
        <translation>Додај фасциклу...</translation>
    </message>
</context>
<context>
    <name>BrowserApplication</name>
    <message>
        <source>There are %1 windows and %2 tabs open
Do you want to quit anyway?</source>
        <translation>Отворено је  %1 прозор(а) и %2 језичак(а)
Свеједно напустити?</translation>
    </message>
    <message>
        <source>Restore failed</source>
        <translation>Повраћај није успео</translation>
    </message>
    <message>
        <source>Arora crashed while trying to restore this session.  Should I try again?</source>
        <translation>Арора се срушила у покушају да поврати сесију. Покушати поново?</translation>
    </message>
</context>
<context>
    <name>BrowserMainWindow</name>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Фајл</translation>
    </message>
    <message>
        <source>&amp;New Window</source>
        <translation>Нови &amp;прозор</translation>
    </message>
    <message>
        <source>&amp;Open File...</source>
        <translation>&amp;Отвори фајл...</translation>
    </message>
    <message>
        <source>Open &amp;Location...</source>
        <translation>Отвори &amp;локацију...</translation>
    </message>
    <message>
        <source>&amp;Save As...</source>
        <translation>&amp;Сачувај као...</translation>
    </message>
    <message>
        <source>&amp;Import Bookmarks...</source>
        <translation>&amp;Увези маркере...</translation>
    </message>
    <message>
        <source>&amp;Export Bookmarks...</source>
        <translation>&amp;Извези маркере...</translation>
    </message>
    <message>
        <source>P&amp;rint Preview...</source>
        <translation>П&amp;реглед штампе...</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>Ш&amp;тампа...</translation>
    </message>
    <message>
        <source>Private &amp;Browsing...</source>
        <translation>&amp;Приватно прегледање...</translation>
    </message>
    <message>
        <source>Close Window</source>
        <translation>Затвори прозор</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Напусти</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Уређивање</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Опозови</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>&amp;Понови</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>Исе&amp;ци</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Копирај</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>&amp;Налепи</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>Нађ&amp;и</translation>
    </message>
    <message>
        <source>Find Nex&amp;t</source>
        <translation>Нађи &amp;следеће</translation>
    </message>
    <message>
        <source>Find P&amp;revious</source>
        <translation>Нађи &amp;претходно</translation>
    </message>
    <message>
        <source>Ctrl+,</source>
        <translation>Ctrl+,</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>Прика&amp;з</translation>
    </message>
    <message>
        <source>Ctrl+|</source>
        <translation>Ctrl+|</translation>
    </message>
    <message>
        <source>Ctrl+/</source>
        <translation>Ctrl+/</translation>
    </message>
    <message>
        <source>Show Menu Bar</source>
        <translation>Прикажи траку менија</translation>
    </message>
    <message>
        <source>&amp;Reload Page</source>
        <translation>Поново &amp;учитај страницу</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Заустави</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>&amp;Увећај</translation>
    </message>
    <message>
        <source>Zoom &amp;Normal</source>
        <translation>По&amp;дразумевано увећање</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>&amp;Умањи</translation>
    </message>
    <message>
        <source>Zoom &amp;Text Only</source>
        <translation>Увећај само &amp;текст</translation>
    </message>
    <message>
        <source>Page S&amp;ource</source>
        <translation>И&amp;зворни код странице</translation>
    </message>
    <message>
        <source>Ctrl+Alt+U</source>
        <translation>Ctrl+Alt+U</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Цео екран</translation>
    </message>
    <message>
        <source>Hi&amp;story</source>
        <translation>Ист&amp;оријат</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Назад</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Напред</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Моја страница</translation>
    </message>
    <message>
        <source>Restore Last Session</source>
        <translation>Поврати претходну сесију</translation>
    </message>
    <message>
        <source>&amp;Bookmarks</source>
        <translation>&amp;Маркери</translation>
    </message>
    <message>
        <source>Show All Bookmarks...</source>
        <translation>Прикажи све маркере...</translation>
    </message>
    <message>
        <source>Add Bookmark...</source>
        <translation>Додај маркер...</translation>
    </message>
    <message>
        <source>Add Folder...</source>
        <translation>Додај фасциклу...</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Прозор</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;Алатке</translation>
    </message>
    <message>
        <source>Web &amp;Search</source>
        <translation>&amp;Веб претрага</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <comment>Web Search</comment>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>&amp;Clear Private Data</source>
        <translation>Очисти п&amp;риватне податке</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Delete</source>
        <comment>Clear Private Data</comment>
        <translation>Ctrl+Shift+Delete</translation>
    </message>
    <message>
        <source>Enable Web &amp;Inspector</source>
        <translation>Омогући &amp;веб инспектор</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>По&amp;моћ</translation>
    </message>
    <message>
        <source>Switch application language </source>
        <translation>Промени језик програма</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>О &amp;Qt-у</translation>
    </message>
    <message>
        <source>About &amp;%1</source>
        <comment>About Browser</comment>
        <translation>О &amp;Арори </translation>
    </message>
    <message>
        <source>Navigation</source>
        <translation>Навигација</translation>
    </message>
    <message>
        <source>Show Status Bar</source>
        <translation>Прикажи траку стања</translation>
    </message>
    <message>
        <source>Hide Status Bar</source>
        <translation>Сакриј траку стања</translation>
    </message>
    <message>
        <source>Show Toolbar</source>
        <translation>Прикажи траку алатки</translation>
    </message>
    <message>
        <source>Hide Toolbar</source>
        <translation>Сакриј траку алатки</translation>
    </message>
    <message>
        <source>Show Bookmarks Bar</source>
        <translation>Прикажи траку маркера</translation>
    </message>
    <message>
        <source>Hide Bookmarks Bar</source>
        <translation>Сакриј траку маркера</translation>
    </message>
    <message>
        <source>%1 - Arora</source>
        <comment>Page title and Browser name</comment>
        <translation>%1 - Aрора</translation>
    </message>
    <message>
        <source>Open Web Resource</source>
        <translation>Отвори веб ресурс</translation>
    </message>
    <message>
        <source>Web Resources (*.html *.htm *.svg *.png *.gif *.svgz);;All files (*.*)</source>
        <translation>Веб ресурси (*.html *.htm *.svg *.png *.gif *.svgz);;Сви фајлови (*.*)</translation>
    </message>
    <message>
        <source>Print Document</source>
        <translation>Штампај документ</translation>
    </message>
    <message>
        <source>Are you sure you want to turn on private browsing?</source>
        <translation>Да ли сте сигурни да желите да укључите приватно прегледање?</translation>
    </message>
    <message>
        <source>Are you sure you want to close the window?  There are %1 tabs open</source>
        <translation>Да ли сте сигурни да желите да затворите прозор? Отворен(о) је %1 језичак(а)</translation>
    </message>
    <message>
        <source>Web Inspector</source>
        <translation>Веб инспектор</translation>
    </message>
    <message>
        <source>The web inspector will only work correctly for pages that were loaded after enabling.
Do you want to reload all pages?</source>
        <translation>Веб инспектор ће исправно радити само на страницама учитаним након његовог укључивања.
Да ли желите да поново учитате све странице?</translation>
    </message>
    <message>
        <source>Stop loading the current page</source>
        <translation>Заустави учитавање тренутне странице</translation>
    </message>
    <message>
        <source>Reload the current page</source>
        <translation>Поново учитај тренутну страницу</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Пријеми</translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <comment>Download Manager</comment>
        <translation>Ctrl+Y</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Подразумевано</translation>
    </message>
    <message>
        <source>Text Encoding</source>
        <translation>Кодирање текста</translation>
    </message>
    <message>
        <source>Alt+Ctrl+B</source>
        <translation>Alt+Ctrl+B</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation>Изабери &amp;све</translation>
    </message>
    <message>
        <source>Options...</source>
        <translation>Опције...</translation>
    </message>
    <message>
        <source>Configure Search Engines...</source>
        <translation>Подеси моторе претраге...</translation>
    </message>
    <message>
        <source>&amp;Ad Block...</source>
        <translation>&amp;Адблок...</translation>
    </message>
    <message>
        <source>When private browsing is turned on, some actions concerning your privacy will be disabled:</source>
        <translation>Кад је укључено приватно прегледање онемогућене су неке радње које се тичу ваше приватности:</translation>
    </message>
    <message>
        <source>Webpages are not added to the history.</source>
        <translation>Веб стране се не додају у историјат.</translation>
    </message>
    <message>
        <source>Items are automatically removed from the Downloads window.</source>
        <translation>Ставке се аутоматски уклањају из прозора пријема.</translation>
    </message>
    <message>
        <source>New cookies are not stored, current cookies can&apos;t be accessed.</source>
        <translation>Нови колачићи се не чувају, постојећим се не може приступити.</translation>
    </message>
    <message>
        <source>Site icons won&apos;t be stored.</source>
        <translation>Иконе сајтова се не чувају.</translation>
    </message>
    <message>
        <source>Session won&apos;t be saved.</source>
        <translation>Сесије се не снимају.</translation>
    </message>
    <message>
        <source>Searches are not added to the pop-up menu in the search box.</source>
        <translation>Претраге се не додају у искачући мени прозорчића претраге.</translation>
    </message>
    <message>
        <source>No new network cache is written to disk.</source>
        <translation>Мрежни кеш се не дописује на диск.</translation>
    </message>
    <message>
        <source>Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
        <translation>Док не затворите прозор и даље можете кликнути на „Напред“ и „Назад“ да би сте се вратили на претходно отваране странице.</translation>
    </message>
    <message>
        <source>Private Browsing</source>
        <translation>Приватно прегледање</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Очисти</translation>
    </message>
</context>
<context>
    <name>ClearPrivateData</name>
    <message>
        <source>Clear Private Data</source>
        <translation>Очисти приватне податке</translation>
    </message>
    <message>
        <source>Clear the following items:</source>
        <translation>Очисти следеће ставке:</translation>
    </message>
    <message>
        <source>&amp;Browsing History</source>
        <translation>историјат &amp;претраге</translation>
    </message>
    <message>
        <source>&amp;Download History</source>
        <translation>историјат п&amp;реузимања</translation>
    </message>
    <message>
        <source>&amp;Search History</source>
        <translation>историјат пр&amp;етраге</translation>
    </message>
    <message>
        <source>&amp;Cookies</source>
        <translation>&amp;колачиће</translation>
    </message>
    <message>
        <source>C&amp;ached Web Pages</source>
        <translation>кеширане &amp;веб странице</translation>
    </message>
    <message>
        <source>Website &amp;Icons</source>
        <translation>&amp;иконе веб сајтова</translation>
    </message>
    <message>
        <source>Clear &amp;Private Data</source>
        <translation>Очисти приватне по&amp;датке</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Одустани</translation>
    </message>
</context>
<context>
    <name>ClickToFlash</name>
    <message>
        <source>Load</source>
        <translation>Учитај</translation>
    </message>
    <message>
        <source>Load All</source>
        <translation>Учитај све</translation>
    </message>
    <message>
        <source>Add %1 to Whitelist</source>
        <translation>Додај %1 на белу листу</translation>
    </message>
    <message>
        <source>Remove from Whitelist</source>
        <translation>Уклони са беле листе</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Подешавање</translation>
    </message>
    <message>
        <source>Load Flash</source>
        <translation>Учитај флеш</translation>
    </message>
</context>
<context>
    <name>ClickToFlashSettings</name>
    <message>
        <source>Whitelist sites</source>
        <translation>Сајтови на белој листи</translation>
    </message>
</context>
<context>
    <name>CookieExceptionsModel</name>
    <message>
        <source>Website</source>
        <translation>Веб сајт</translation>
    </message>
    <message>
        <source>Rule</source>
        <translation>Правило</translation>
    </message>
    <message>
        <source>Allow</source>
        <translation>Дозволи</translation>
    </message>
    <message>
        <source>Block</source>
        <translation>Блокирај</translation>
    </message>
    <message>
        <source>Allow For Session</source>
        <translation>Дозволи у току сесије</translation>
    </message>
</context>
<context>
    <name>CookieModel</name>
    <message>
        <source>Website</source>
        <translation>Веб сајт</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Име</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>Путања</translation>
    </message>
    <message>
        <source>Secure</source>
        <translation>Сигурно</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>Истиче</translation>
    </message>
    <message>
        <source>Contents</source>
        <translation>Садржај</translation>
    </message>
    <message>
        <source>true</source>
        <translation>тачно</translation>
    </message>
    <message>
        <source>false</source>
        <translation>нетачно</translation>
    </message>
    <message>
        <source>Session cookie</source>
        <translation>Колачић сесије</translation>
    </message>
</context>
<context>
    <name>CookiesDialog</name>
    <message>
        <source>Cookies</source>
        <translation>Колачићи</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Уклони</translation>
    </message>
    <message>
        <source>Remove &amp;All Cookies</source>
        <translation>Уклони &amp;све колачиће</translation>
    </message>
    <message>
        <source>Add &amp;Rule</source>
        <translation>Додај &amp;правило</translation>
    </message>
</context>
<context>
    <name>CookiesExceptionsDialog</name>
    <message>
        <source>Cookie Exceptions</source>
        <translation>Изузеци за колачиће</translation>
    </message>
    <message>
        <source>New Exception</source>
        <translation>Нови изузетак</translation>
    </message>
    <message>
        <source>Domain:</source>
        <translation>Домен:</translation>
    </message>
    <message>
        <source>Block</source>
        <translation>Блокирај</translation>
    </message>
    <message>
        <source>Allow For Session</source>
        <translation>Дозволи у току сесије</translation>
    </message>
    <message>
        <source>Allow</source>
        <translation>Дозволи</translation>
    </message>
    <message>
        <source>Exceptions</source>
        <translation>Изузеци</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Уклони</translation>
    </message>
    <message>
        <source>Remove &amp;All</source>
        <translation>Уклони &amp;све</translation>
    </message>
</context>
<context>
    <name>DownloadDialog</name>
    <message>
        <source>Downloads</source>
        <translation>Преузимања</translation>
    </message>
    <message>
        <source>Clean up</source>
        <translation>Очисти</translation>
    </message>
    <message>
        <source>0 Items</source>
        <translation>Нема ставки</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>Ico</source>
        <translation>Икона</translation>
    </message>
    <message>
        <source>Filename</source>
        <translation>Име фајла</translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation>Покушајте поново</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Заустави</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Отвори</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>Сачувај фајл</translation>
    </message>
    <message>
        <source>Download canceled: %1</source>
        <translation>Преузимање отказано: %1</translation>
    </message>
    <message>
        <source>Error opening output file: %1</source>
        <translation>Грешка при отварању излазног фајла: %1</translation>
    </message>
    <message>
        <source>Error saving: %1</source>
        <translation>Грешка при чувању: %1</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>Грешка на мрежи: %1</translation>
    </message>
    <message>
        <source>%1 of %2 (%3/sec) - %4</source>
        <translation>%1 од %2 (%3/сек) - %4</translation>
    </message>
    <message>
        <source>?</source>
        <translation>?</translation>
    </message>
    <message>
        <source>%1 of %2 - Stopped</source>
        <translation>%1 од %2 - Заустављено</translation>
    </message>
    <message>
        <source>Download directory (%1) couldn&apos;t be created.</source>
        <translation>Фасцикла за преузимања (%1) не може бити направљена.</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>There are %1 downloads in progress
Do you want to quit anyway?</source>
        <translation>У току су %1 преузимања
Свеједно напустити?</translation>
    </message>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation>
            <numerusform>%n преузимање</numerusform>
            <numerusform>%n  преузимања</numerusform>
            <numerusform>%n  преузимања</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minutes remaining</source>
        <translation>
            <numerusform>%n минут је преостао</numerusform>
            <numerusform>%n минуте су преостале</numerusform>
            <numerusform>%n минута је преостало</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n seconds remaining</source>
        <translation>
            <numerusform>%n секунда је преостала</numerusform>
            <numerusform>%n секунде су преостале</numerusform>
            <numerusform>%n  секунди је преостало</numerusform>
        </translation>
    </message>
    <message>
        <source>bytes</source>
        <translation>бајтова</translation>
    </message>
    <message>
        <source>kB</source>
        <translation>kB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>GB</source>
        <translation>GB</translation>
    </message>
</context>
<context>
    <name>FileAccessReply</name>
    <message>
        <source>No Error</source>
        <translation>Без грешке</translation>
    </message>
    <message>
        <source>Error opening: %1: No such file or directory</source>
        <translation>Грешка при отварању: %1: Не постоји такав фајл или фасцикла</translation>
    </message>
    <message>
        <source>Unable to read %1</source>
        <translation>Немогуће читање %1</translation>
    </message>
    <message>
        <source>Contents of %1</source>
        <translation>Садржај %1</translation>
    </message>
    <message>
        <source>%1 KB</source>
        <translation>%1 КБ</translation>
    </message>
</context>
<context>
    <name>HistoryDialog</name>
    <message>
        <source>Open</source>
        <translation>Отвори</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копирај</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Обриши</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Историјат</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Уклони</translation>
    </message>
    <message>
        <source>Remove &amp;All</source>
        <translation>Уклони &amp;све</translation>
    </message>
</context>
<context>
    <name>HistoryMenu</name>
    <message>
        <source>Show All History</source>
        <translation>Прикажи цео историјат</translation>
    </message>
    <message>
        <source>Clear History...</source>
        <translation>Очисти историјат...</translation>
    </message>
    <message>
        <source>Clear History</source>
        <translation>Очисти историјат</translation>
    </message>
    <message>
        <source>Do you want to clear the history?</source>
        <translation>Желите ли да очистите историјат?</translation>
    </message>
</context>
<context>
    <name>HistoryModel</name>
    <message>
        <source>Title</source>
        <translation>Назив</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Адреса</translation>
    </message>
</context>
<context>
    <name>HistoryTreeModel</name>
    <message>
        <source>Earlier Today</source>
        <translation>Раније у току дана</translation>
    </message>
    <message numerus="yes">
        <source>%n item(s)</source>
        <translation>
            <numerusform>%n ставка</numerusform>
            <numerusform>%n ставке</numerusform>
            <numerusform>%n ставки</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>JavaScriptAroraObject</name>
    <message>
        <source>Welcome to Arora!</source>
        <translation>Добродошли у Арору !</translation>
    </message>
    <message>
        <source>Arora Start</source>
        <translation>Aрорина почетна</translation>
    </message>
    <message>
        <source>Search!</source>
        <translation>Претражи!</translation>
    </message>
    <message>
        <source>Search results provided by</source>
        <translation>Резултате претраге омогућује</translation>
    </message>
    <message>
        <source>About Arora</source>
        <translation>О Арори </translation>
    </message>
</context>
<context>
    <name>LanguageManager</name>
    <message>
        <source>Choose language</source>
        <translation>Изаберите језик</translation>
    </message>
    <message>
        <source>&lt;p&gt;You can run with a different language than&lt;br&gt;the operating system default.&lt;/p&gt;&lt;p&gt;Please choose the language which should be used&lt;/p&gt;</source>
        <translation>&lt;p&gt;Можете поставити различит језик од оног&lt;br&gt;који оперативни систем подразумева.&lt;/p&gt;&lt;p&gt;Изаберите језик који ћете користити&lt;/p&gt;</translation>
    </message>
    <message>
        <source>No translation files are installed at %1.</source>
        <translation>Нема инсталираних фајлова превода у %1.</translation>
    </message>
</context>
<context>
    <name>NetworkAccessManager</name>
    <message>
        <source>&lt;qt&gt;Enter username and password for &quot;%1&quot; at %2&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Уреди корисничко име и лозинку за &quot;%1&quot; на  %2&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>&lt;qt&gt;Connect to proxy &quot;%1&quot; using:&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Повежи се на прокси &quot;%1&quot; користећи: &lt;/qt&gt;</translation>
    </message>
    <message>
        <source> - SSL Errors</source>
        <translation>- SSL грешке</translation>
    </message>
    <message>
        <source>&lt;qt&gt;Certificates:&lt;br/&gt;%1&lt;br/&gt;Do you want to accept all these certificates?&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Сертификати:&lt;br/&gt;%1&lt;br/&gt;Да ли желите да прихватите све ове сертификате?&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>&lt;qt&gt;SSL Errors:&lt;br/&gt;&lt;br/&gt;for: &lt;tt&gt;%1&lt;/tt&gt;&lt;ul&gt;&lt;li&gt;%2&lt;/li&gt;&lt;/ul&gt;

Do you want to ignore these errors?&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;SSL грешке:&lt;br/&gt;&lt;br/&gt;за: &lt;tt&gt;%1&lt;/tt&gt;&lt;ul&gt;&lt;li&gt;%2&lt;/li&gt;&lt;/ul&gt;
Да ли желите да занемарите ове грешке?&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>Issuer: %1</source>
        <translation>Издавач: %1</translation>
    </message>
    <message>
        <source>Not valid before: %1</source>
        <translation>Није валидо пре: %1</translation>
    </message>
    <message>
        <source>Valid until: %1</source>
        <translation>Валидно до: %1</translation>
    </message>
    <message>
        <source>Alternate Names:</source>
        <translation>Алтернативни називи:</translation>
    </message>
</context>
<context>
    <name>OpenSearchDialog</name>
    <message>
        <source>Open File</source>
        <translation>Отвори фајл</translation>
    </message>
    <message>
        <source>OpenSearch</source>
        <translation>Отвори претрагу</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Грешка</translation>
    </message>
    <message>
        <source>%1 is not a valid OpenSearch 1.1 description or is already on your list.</source>
        <translation>%1  није исправан OpenSearch 1.1 опис или се већ налази на вашој листи.</translation>
    </message>
    <message>
        <source>You must have at least one search engine in here.</source>
        <translation>Мора постојати барем један мотор претраге.</translation>
    </message>
    <message>
        <source>OpenSearch Manager</source>
        <translation>Овори управник претраге</translation>
    </message>
    <message>
        <source>&amp;Restore Defaults</source>
        <translation>&amp;Подразумевано</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Обриши</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Додај</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Затвори</translation>
    </message>
</context>
<context>
    <name>OpenSearchEngineModel</name>
    <message>
        <source>&lt;strong&gt;Description:&lt;/strong&gt; %1</source>
        <translation>&lt;strong&gt;Опис:&lt;/strong&gt; %1</translation>
    </message>
    <message>
        <source>&lt;strong&gt;Provides contextual suggestions&lt;/strong&gt;</source>
        <translation>&lt;strong&gt;Даје предлоге из садржаја&lt;/strong&gt;</translation>
    </message>
    <message>
        <source>Comma-separated list of keywords that may be entered in the location barfollowed by search terms to search with this engine</source>
        <translation>Списак зарезом раздвојених кључних речи које могу бити унете у траку локације заједно са изразима са претрагу у овом мотору претраге</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Име</translation>
    </message>
    <message>
        <source>Keywords</source>
        <translation>Кључне речи</translation>
    </message>
</context>
<context>
    <name>OpenSearchManager</name>
    <message>
        <source>Do you want to add the following engine to your list of search engines?&lt;br /&gt;&lt;br /&gt;Name: %1&lt;br /&gt;Searches on: %2</source>
        <translation>Желите ли да додате следећи мотор на вашу листу мотора претраге? &lt;br /&gt;&lt;br /&gt;Име: %1&lt;br /&gt;Претражује на: %2</translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <source>Authentication Required</source>
        <translation>Неопходна аутентификација</translation>
    </message>
    <message>
        <source>DUMMY ICON</source>
        <translation>DUMMY ICON</translation>
    </message>
    <message>
        <source>INTRO TEXT DUMMY</source>
        <translation>INTRO TEXT DUMMY</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Корисничко име:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Лозинка:</translation>
    </message>
</context>
<context>
    <name>PlainTextEditSearch</name>
    <message>
        <source>Not Found</source>
        <translation>Не постоји</translation>
    </message>
</context>
<context>
    <name>ProxyDialog</name>
    <message>
        <source>Proxy Authentication</source>
        <translation>Аутентификација проксија</translation>
    </message>
    <message>
        <source>Connect to proxy</source>
        <translation>Повежи се на прокси</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Корисничко име:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Лозинка:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The file is not an XBEL version 1.0 file.</source>
        <translation>Фајл није типа ИксБЕЛ 1.0.</translation>
    </message>
    <message>
        <source>Unknown title</source>
        <translation>Непознат назив</translation>
    </message>
    <message>
        <source>The file is not an OpenSearch 1.1 file.</source>
        <translation>Фајл није OpenSearch 1.1 типа.</translation>
    </message>
</context>
<context>
    <name>SearchBanner</name>
    <message>
        <source>Done</source>
        <translation>Завршено</translation>
    </message>
    <message>
        <source>Highlight All</source>
        <translation>Истакни све</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Претражи</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Preferences</source>
        <translation>Поставке</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Опште</translation>
    </message>
    <message>
        <source>On startup:</source>
        <translation>При покретању:</translation>
    </message>
    <message>
        <source>Show my home page</source>
        <translation>прикажи домаћу страницу</translation>
    </message>
    <message>
        <source>Show a blank page</source>
        <translation>прикажи празну страницу</translation>
    </message>
    <message>
        <source>Restore windows and tabs from last time</source>
        <translation>поврати прозоре и језичке од прошлог пута</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>Домаћа страница:</translation>
    </message>
    <message>
        <source>Set to current page</source>
        <translation>Постави текућу страницу</translation>
    </message>
    <message>
        <source>Remove history items:</source>
        <translation>Уклони ставке историјата:</translation>
    </message>
    <message>
        <source>After one day</source>
        <translation>после једног дана</translation>
    </message>
    <message>
        <source>After one week</source>
        <translation>после једне седмице</translation>
    </message>
    <message>
        <source>After two weeks</source>
        <translation>после две седмице</translation>
    </message>
    <message>
        <source>After one month</source>
        <translation>после једног месеца</translation>
    </message>
    <message>
        <source>After one year</source>
        <translation>после једне године</translation>
    </message>
    <message>
        <source>Manually</source>
        <translation>ручно</translation>
    </message>
    <message>
        <source>On application exit</source>
        <translation>при напуштању програма</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Преузимања</translation>
    </message>
    <message>
        <source>Ask for a destination each time</source>
        <translation>Увек питај за одредиште</translation>
    </message>
    <message>
        <source>Use this destination:</source>
        <translation>Користи следеће одредиште:</translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation>Изглед</translation>
    </message>
    <message>
        <source>Standard font:</source>
        <translation>Стандардни фонт:</translation>
    </message>
    <message>
        <source>Select...</source>
        <translation>Изаберите...</translation>
    </message>
    <message>
        <source>Fixed-width font:</source>
        <translation>Фиксни фонт:</translation>
    </message>
    <message>
        <source>Preferred languages for viewing webpages in:</source>
        <translation>Пожељни језици за прегледање веб страница:</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>Приватност</translation>
    </message>
    <message>
        <source>Web Content</source>
        <translation>Веб садржај</translation>
    </message>
    <message>
        <source>Block Popup Windows</source>
        <translation>Блокирај искачуће прозоре</translation>
    </message>
    <message>
        <source>Enable Plugins</source>
        <translation>Омогући прикључке</translation>
    </message>
    <message>
        <source>Use ClickToFlash on flash plugins</source>
        <translation>Користи &quot;Кликни за флеш&quot; за флеш прикључке</translation>
    </message>
    <message>
        <source>Enable Javascript</source>
        <translation>Омогући Јаваскрипт</translation>
    </message>
    <message>
        <source>View Images</source>
        <translation>Прикажи слике</translation>
    </message>
    <message>
        <source>Cookies</source>
        <translation>Колачићи</translation>
    </message>
    <message>
        <source>Accept Cookies:</source>
        <translation>Прихвати колачиће:</translation>
    </message>
    <message>
        <source>Always</source>
        <translation>увек</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>никад</translation>
    </message>
    <message>
        <source>Only from sites you navigate to</source>
        <translation>само са веб сајтова које посећујем</translation>
    </message>
    <message>
        <source>Exceptions...</source>
        <translation>Изузеци... </translation>
    </message>
    <message>
        <source>Keep Cookies Until:</source>
        <translation>Задржи колачиће док не:</translation>
    </message>
    <message>
        <source>They expire</source>
        <translation>истекну</translation>
    </message>
    <message>
        <source>I exit the application</source>
        <translation>напустим програм</translation>
    </message>
    <message>
        <source>At most 90 days</source>
        <translation>истекне највише 90 дана</translation>
    </message>
    <message>
        <source>Cookies...</source>
        <translation>Колачићи...</translation>
    </message>
    <message>
        <source>Filter Tracking Cookies</source>
        <translation>Филтрирај колачиће пратиоце</translation>
    </message>
    <message>
        <source>Tabs</source>
        <translation>Језичци</translation>
    </message>
    <message>
        <source>Select tabs and windows as they are created</source>
        <translation>Одабери језичке и прозоре при њиховом настајању</translation>
    </message>
    <message>
        <source>Confirm when closing multiple tabs or windows</source>
        <translation>Потврда при затварању више прозора или језичака</translation>
    </message>
    <message>
        <source>Show only one close button instead of one for each tab</source>
        <translation>Прикажи само једно дугме за затварање уместо једног по сваком језичку</translation>
    </message>
    <message>
        <source>Quit the application when last tab is closed</source>
        <translation>Напусти програм кад је последњи језичак затворен</translation>
    </message>
    <message>
        <source>Opening links</source>
        <translation>Отварам везе</translation>
    </message>
    <message>
        <source>Links that want to open in a new window:</source>
        <translation>Везе које желе да се отворе у новом прозору:</translation>
    </message>
    <message>
        <source>In a new window</source>
        <translation>у новом прозору</translation>
    </message>
    <message>
        <source>In a new selected tab in the current window</source>
        <translation>у изабраном новом језичку тренутног прозора</translation>
    </message>
    <message>
        <source>In a new tab in the current window</source>
        <translation>у новом језичку тренутног прозора</translation>
    </message>
    <message>
        <source>In the current tab</source>
        <translation>у тренутном језичку</translation>
    </message>
    <message>
        <source>Open links from applications:</source>
        <translation>Отварај везе из програма:</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Прокси</translation>
    </message>
    <message>
        <source>Use proxy server</source>
        <translation>Користи прокси сервер</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Тип:</translation>
    </message>
    <message>
        <source>Socks5</source>
        <translation>СОКС5</translation>
    </message>
    <message>
        <source>Http (Secure)</source>
        <translation>ХТТП (Безбедно)</translation>
    </message>
    <message>
        <source>Http (Transparent)</source>
        <translation>ХТТП (Транспарентно)</translation>
    </message>
    <message>
        <source>Host name:</source>
        <translation>Име домаћина:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Порт:</translation>
    </message>
    <message>
        <source>User Name:</source>
        <translation>Корисничко име:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Лозинка:</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Напредно</translation>
    </message>
    <message>
        <source>Style Sheet:</source>
        <translation>Опис стила:</translation>
    </message>
    <message>
        <source>Enable network cache</source>
        <translation>Омогући мрежни кеш</translation>
    </message>
    <message>
        <source>Maximum Size:</source>
        <translation>Максимална величина:</translation>
    </message>
    <message>
        <source> MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>Use the default search engine as fallback when the URL given by the user is invalid</source>
        <translation>Користи подразумевани мотор претраге као испомоћ уколико је УРЛ задат од стране корисника неисправан</translation>
    </message>
    <message>
        <source>Choose Directory...</source>
        <translation>Изаберите фасциклу...</translation>
    </message>
    <message>
        <source>A cookie session ends:</source>
        <translation>Колачић сесије истиче:</translation>
    </message>
    <message>
        <source>When I exit the application</source>
        <translation>кад напустим програм</translation>
    </message>
    <message>
        <source>1 day</source>
        <translation>за 1 дан</translation>
    </message>
    <message>
        <source>2 days</source>
        <translation>за 2 дана</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>за 3 дана</translation>
    </message>
    <message>
        <source>7 days</source>
        <translation>за 7 дана</translation>
    </message>
    <message>
        <source>30 days</source>
        <translation>за 30 дана</translation>
    </message>
    <message>
        <source>AutoFill</source>
        <translation>Смопопуњавање</translation>
    </message>
    <message>
        <source>AutoFill web forms:</source>
        <translation>Самопопуњавање веб образаца:</translation>
    </message>
    <message>
        <source>User names and passwords</source>
        <translation>Корисничка имена и лозинке</translation>
    </message>
    <message>
        <source>Edit...</source>
        <translation>Уреди...</translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation>Прегледај...</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Restart required</source>
        <translation>Захтева се поновно покретање</translation>
    </message>
    <message>
        <source>The network cache configuration has changed. So that it can be taken into account, the browser has to be restarted.</source>
        <translation>Подешавање мрежног кеша је промењено. Да би било узето у обзир прегледач мора бити поново покренут.</translation>
    </message>
    <message>
        <source>Choose Directory</source>
        <translation>Изаберите фасциклу</translation>
    </message>
    <message>
        <source>Choose CSS File</source>
        <translation>Изаберите ЦСС фајл</translation>
    </message>
</context>
<context>
    <name>SourceViewer</name>
    <message>
        <source>Loading...</source>
        <translation>Учитавање...</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Уређивање</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>Нађ&amp;и</translation>
    </message>
    <message>
        <source>Source of Page %1</source>
        <translation>Изворни код странице %1</translation>
    </message>
</context>
<context>
    <name>TabBar</name>
    <message>
        <source>Show Tab Bar</source>
        <translation>Прикажи траку језичака</translation>
    </message>
    <message>
        <source>Hide Tab Bar</source>
        <translation>Сакриј траку језичака</translation>
    </message>
    <message>
        <source>Duplicate Tab</source>
        <translation>Дуплирај језичак</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>&amp;Затвори језичак</translation>
    </message>
    <message>
        <source>Close &amp;Other Tabs</source>
        <translation>Затвори &amp;остале језичке</translation>
    </message>
    <message>
        <source>Reload Tab</source>
        <translation>Поново учитај језичак</translation>
    </message>
    <message>
        <source>Reload All Tabs</source>
        <translation>Поново учитај све језичке</translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <source>Untitled</source>
        <translation>Неименовано</translation>
    </message>
    <message>
        <source>Saved Tabs</source>
        <translation>Сачувај језичке</translation>
    </message>
    <message>
        <source>Do you really want to close this page?</source>
        <translation>Да ли заиста желите да затворите ову страницу?</translation>
    </message>
    <message>
        <source>You have modified this page and when closing it you would lose the modification.
Do you really want to close this page?
</source>
        <translation>Изменили сте ову страницу и њеним затварањем ћете изгубити измене.
Да ли заиста желите да затворите ову страницу?
</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation>Учитавање...</translation>
    </message>
    <message>
        <source>Loading %1% (%2 %3)...</source>
        <translation>Учитавам  %1% (%2 %3)...</translation>
    </message>
    <message>
        <source>Finished loading</source>
        <translation>Учитавање завршено</translation>
    </message>
    <message>
        <source>Failed to load</source>
        <translation>Грешка при учитавању</translation>
    </message>
    <message>
        <source>Show Next Tab</source>
        <translation>Прикажи наредни језичак</translation>
    </message>
    <message>
        <source>Ctrl-]</source>
        <translation>Ctrl-]</translation>
    </message>
    <message>
        <source>Show Previous Tab</source>
        <translation>Прикажи претходни језичак</translation>
    </message>
    <message>
        <source>Ctrl-[</source>
        <translation>Ctrl-[</translation>
    </message>
    <message>
        <source>Recently Closed Tabs</source>
        <translation>Недавно затворени језичци</translation>
    </message>
    <message>
        <source>New &amp;Tab</source>
        <translation>Нови &amp;језичак</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>&amp;Затвори језичак</translation>
    </message>
    <message>
        <source>Bookmark All Tabs</source>
        <translation>Маркирај све језичке</translation>
    </message>
</context>
<context>
    <name>ToolbarSearch</name>
    <message>
        <source>Suggestions</source>
        <translation>Предлози</translation>
    </message>
    <message>
        <source>No Recent Searches</source>
        <translation>Нема скорашњих претрага</translation>
    </message>
    <message>
        <source>Recent Searches</source>
        <translation>Скорашње претраге</translation>
    </message>
    <message>
        <source>Add &apos;%1&apos;</source>
        <translation>Додај &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Clear Recent Searches</source>
        <translation>Уклони скорашње претраге</translation>
    </message>
</context>
<context>
    <name>WebPage</name>
    <message>
        <source>Error loading page: %1</source>
        <translation>Грешка при учитавању странице: %1</translation>
    </message>
    <message>
        <source>When connecting to: %1.</source>
        <translation>При повезивању на: %1.</translation>
    </message>
    <message>
        <source>Check the address for errors such as &lt;b&gt;ww&lt;/b&gt;.arora-browser.org instead of &lt;b&gt;www&lt;/b&gt;.arora-browser.org</source>
        <translation>Проверите адресу за грешке попут &lt;b&gt;ww/&lt;/b&gt;.arora-browser.org/ /уместо &lt;b&gt;www/&lt;/b&gt;.arora-browser.org/ </translation>
    </message>
    <message>
        <source>If the address is correct, try checking the network connection.</source>
        <translation>Уколико је адреса исправна, покушајте провером мрежне повезаности.</translation>
    </message>
    <message>
        <source>If your computer or network is protected by a firewall or proxy, make sure that the browser is permitted to access the network.</source>
        <translation>Уколико су ваш рачунар или мрежа заштићени фајерволом или проксијем постарајте се да прегледач има дозволе за приступ мрежи.</translation>
    </message>
    <message>
        <source>Resending POST request</source>
        <translation>Поново шаљем ПОСТ захтев</translation>
    </message>
    <message>
        <source>In order to display the site, the request along with all the data must be sent once again, which may lead to some unexpected behaviour of the site e.g. the same action might be performed once again. Do you want to continue anyway?</source>
        <translation>Да би сајт био приказан, захтев заједно са свим подацима мора бити поново послат, што може довести до непредвидљивог понашања самог сајта, нпр. иста радња може бити поново изведена. Да ли свеједно желите да наставите?  </translation>
    </message>
</context>
<context>
    <name>WebView</name>
    <message>
        <source>Open in New &amp;Window</source>
        <translation>Отвори у новом &amp;прозору</translation>
    </message>
    <message>
        <source>Open in New &amp;Tab</source>
        <translation>Отвори у новом &amp;језичку</translation>
    </message>
    <message>
        <source>Save Lin&amp;k</source>
        <translation>Сачувај &amp;везу</translation>
    </message>
    <message>
        <source>&amp;Bookmark This Link</source>
        <translation>&amp;Маркирај ову везу</translation>
    </message>
    <message>
        <source>&amp;Copy Link Location</source>
        <translation>&amp;Копирај адресу везе</translation>
    </message>
    <message>
        <source>Open Image in New &amp;Window</source>
        <translation>Отвори слику у новом &amp;прозору</translation>
    </message>
    <message>
        <source>Open Image in New &amp;Tab</source>
        <translation>Отвори слику у новом &amp;језичку </translation>
    </message>
    <message>
        <source>&amp;Save Image</source>
        <translation>&amp;Сачувај слику</translation>
    </message>
    <message>
        <source>&amp;Copy Image</source>
        <translation>&amp;Копирај слику</translation>
    </message>
    <message>
        <source>C&amp;opy Image Location</source>
        <translation>Kо&amp;пирај адресу слике</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation>Учитавање...</translation>
    </message>
    <message>
        <source>Search with...</source>
        <translation>Претражи помоћу...</translation>
    </message>
    <message>
        <source>Add to the toolbar search</source>
        <translation>Додај у траку претраге</translation>
    </message>
    <message>
        <source>Method not supported</source>
        <translation>Метод није подржан</translation>
    </message>
    <message>
        <source>%1 method is not supported.</source>
        <translation>%1 метод није подржан.</translation>
    </message>
    <message>
        <source>Search engine</source>
        <translation>Мотор претраге</translation>
    </message>
    <message>
        <source>Choose the desired search engine</source>
        <translation>Изаберите жељени мотор претраге</translation>
    </message>
    <message>
        <source>Engine name</source>
        <translation>Назив мотора</translation>
    </message>
    <message>
        <source>Type in a name for the engine</source>
        <translation>Унесите назив за мотор</translation>
    </message>
    <message>
        <source>Block Image</source>
        <translation>Блокирај слику</translation>
    </message>
</context>
<context>
    <name>WebViewSearch</name>
    <message>
        <source>Not Found</source>
        <translation>Не постоји</translation>
    </message>
</context>
</TS>
